//
//  AddLocationViewController.m
//  AddLocation
//
//  Created by Greg on 23.10.2013.
//  Copyright (c) 2013 Grzegorz Leszek. All rights reserved.
//

#import "AddLocationViewController.h"
#import "AppDelegate.h"
#import "Shop.h"

@interface AddLocationViewController ()
@property (nonatomic, strong) CLLocationManager *locationManager;
@end

@implementation AddLocationViewController
{
    CLLocation *location;
    
    UITextField *nameTextField;
    UITextField *addressTextField;
    UILabel *latitudeLabel;
    UILabel *longitudeLabel;
}

#pragma mark - Application lifecycle

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

-(void)loadView
{
    [super loadView];
    nameTextField = [[UITextField alloc] init];
    nameTextField.placeholder = @"Name";
    
    addressTextField = [[UITextField alloc] init];
    addressTextField.placeholder = @"Address";
    
    latitudeLabel = [[UILabel alloc] init];
    latitudeLabel.text = @"Latitude: -";
    
    longitudeLabel = [[UILabel alloc] init];
    longitudeLabel.text = @"Longitude: -";
    
    [self.view addSubview:nameTextField];
    [self.view addSubview:addressTextField];
    [self.view addSubview:latitudeLabel];
    [self.view addSubview:longitudeLabel];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	
    self.locationManager = [[CLLocationManager alloc] init];
    self.locationManager.delegate = self;
    self.locationManager.distanceFilter = kCLDistanceFilterNone;
    self.locationManager.desiredAccuracy = kCLLocationAccuracyBest;
    [self.locationManager startUpdatingLocation];
    
    nameTextField.delegate = self;
    addressTextField.delegate = self;
    
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemDone target:self action:@selector(done)];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    CGRect frame1 = CGRectMake(10, 80, 300, 30);
    CGRect frame2 = CGRectMake(10, 130, 300, 30);
    CGRect frame3 = CGRectMake(10, 180, 300, 30);
    CGRect frame4 = CGRectMake(10, 230, 300, 30);
    nameTextField.frame = frame1;
    addressTextField.frame = frame2;
    latitudeLabel.frame = frame3;
    longitudeLabel.frame = frame4;
}

-(void) viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [self.locationManager stopUpdatingLocation];
}

#pragma mark - Resign first responder

- (BOOL)textFieldShouldReturn:(UITextField *)textField {

    [textField resignFirstResponder];
        
    return YES;
}

#pragma mark - Location manager

- (void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations
{
    location = [locations lastObject];
    latitudeLabel.text = [NSString stringWithFormat:@"Latitude: %f",location.coordinate.latitude];
    
    longitudeLabel.text = [NSString stringWithFormat:@"Longitude: %f",location.coordinate.longitude];
}

-(void)locationManager:(CLLocationManager *)manager didFailWithError:(NSError *)error
{
    NSLog(@"Add Location View Controller:%@",[error userInfo]);
}

#pragma mark - Helpers

-(void)save
{
    AppDelegate *appDelegate = (AppDelegate *)[[UIApplication sharedApplication] delegate];
    [Shop shopWithName: nameTextField.text
               address: addressTextField.text
              latitude: location.coordinate.latitude
             longitude: location.coordinate.longitude
              uniqueid: self.dataCount
inManagedObjectContext: [appDelegate managedObjectContext]];
    
    NSError *error = nil;
    if([[appDelegate managedObjectContext] hasChanges] &&
       ![[appDelegate managedObjectContext] save:&error])
    {
        NSLog(@"ListTableViewController error: %@", [error userInfo]);
        abort();
    }
}

-(void) done
{
    if ([nameTextField.text length] <= 0 || [addressTextField.text length] <= 0) {
        UIAlertView *message = [[UIAlertView alloc] initWithTitle:@"name or address is empty"
                                                          message:nil
                                                         delegate:nil
                                                cancelButtonTitle:@"OK"
                                                otherButtonTitles:nil];
        [message show];
        return;
    }
    
    [self save];
    [self.navigationController popToRootViewControllerAnimated:YES];
}

@end